@@ -15,8 +15,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from arjuna.tpi.enums import *
-from arjuna.core.enums import *
+from arjuna.tpi.constant import *
+from arjuna.core.constant import *
 
 TRUES = {"on", "ON", "true", "TRUE", "yes", "YES"}
 FALSES = {"off", "OFF", "false", "FALSE", "no", "NO"}
